"""
Basic example using Abrasio in cloud (paid) mode.

This example demonstrates how to use Abrasio with the cloud browser
service using an API key.

Before running:
    pip install abrasiohttps://nopecha.com/setup#sub_1T4CnfCRwBwvt6ptJ7ibOS5S
    export ABRASIO_API_KEY=sk_live_xxx
"""

import asyncio
import os
import random
import time
from abrasio import Abrasio, FingerprintConfig, AbrasioConfig
from abrasio.utils import human_scroll, human_wait, simulate_reading, human_click, human_type, human_move_to


async def _strip_coep(route):
    """
    Remove Cross-Origin-Embedder-Policy e Cross-Origin-Opener-Policy das respostas
    do site alvo. Sem isso o browser bloqueia o iframe do reCAPTCHA Enterprise
    (google.com não envia Cross-Origin-Resource-Policy, violando o COEP do site).
    """
    try:
        response = await route.fetch()
        headers = {
            k: v for k, v in response.headers.items()
            if k.lower() not in (
                "cross-origin-embedder-policy",
                "cross-origin-opener-policy",
            )
        }
        await route.fulfill(
            status=response.status,
            headers=headers,
            body=await response.body(),
        )
    except Exception:
        await route.continue_()


async def main():
    # Get API key from environment
    api_key = "sk_live_v9mZmBNvZHwblE7-hOwCQ3xgyFE7oeo0kTSu8Nt6p34"#"sk_live_AUEnBxlYgqcm4Cc6smA814Vzk067r6bSiIV7cunCkVA"#"sk_live_Qct3WeYuLhXRxPJdLpP2X8X0YqCwUyLUhPywXwmBsyk"#os.getenv("ABRASIO_API_KEY")
    if not api_key:
        print("Set ABRASIO_API_KEY environment variable to use cloud mode")
        print("Example: export ABRASIO_API_KEY=sk_live_xxx")
        return
    config:AbrasioConfig = FingerprintConfig(
        webgl=True,
        webrtc=True,
        )
    # Cloud mode - with API key and region
    # For local testing use: api_url="http://localhost:8000"
    async with Abrasio(
        api_key ="sk_live_J3x6He9d35C1tCSt2mmuOtcNIFk_rVtwWdU-R_donSo",
        region="br",
        #proxy={"server": "http://network.joinmassive.com:65534", "username": "mpuW15al5h-country-BR-subdivision-SP", "password": "moS1BoA2RbKFIwu9BUr0"},
        #api_key=api_key,
        # api_url="http://localhost:8000",  # Uncomment for local testing
        #region="BR",
        #config=config,
        #device="mobile",
        url="https://www.gov.br",
        #profile_id="355161aee2a8",
        #proxy={"server": "gw-open.netnut.net:5959", "username": "Scrapetech-res-br", "password": "Wg0d5619HrBLesl"},
        #proxy=f'http://Scrapetech-res-us:Wg0d5619HrBLesl@gw-open.netnut.net:5959'
          # Disable WebGL and Canvas for testing
        #headless=True,
        #device="mobile",
        #headless=False,
        humanize=True,
    ) as browser:
        page = await browser.new_page()
        # Live view URL (if enabled on server)
        if browser.live_view_url:
            print(f"Watch live: {browser.live_view_url}")
        await page.goto("https://2captcha.com/demo/recaptcha-v3-enterprise")
        await human_wait(5, 10)
        await human_click(page, '//*[@id="root"]/div[2]/main/div/div/div[1]/section/div/form/div[2]/button[1]')
        await human_wait(5, 10)
        await page.screenshot(path="2captcha.png", full_page=True)
        print("Fingerprint.com test saved to 2captcha.png")
        await page.route("https://cdwfazenda.paas.pr.gov.br/**", _strip_coep)
        await page.goto("https://cdwfazenda.paas.pr.gov.br/cdwportal/certidao/automatica", wait_until="domcontentloaded")
        await human_wait(5,7)  # Wait for login page to load
        #await page.screenshot(path="loginpage.png", full_page=True)
        print("Login page screenshot saved to loginpage.png")
        #await human_click(page, '//*[@id="app"]/div/header/div/button[1]')
        #await human_click(page, 'a.q-item.q-item-type.row.no-wrap.q-item--dense.q-router-link--exact-active.q-router-link--active.q-item--clickable.q-link.cursor-pointer.q-focusable.q-hoverable.app-subitem')
        await page.screenshot(path="home.png", full_page=True)
        await simulate_reading(page, 2, 5)

        await page.wait_for_selector('//*[@id="app"]/div/div[3]/main/form/label/div')
        #await page.locator("#accountId").click()
        #cpf = input("Enter the CPF: ")
        await human_type(page, "03360387000185", '//*[@id="app"]/div/div[3]/main/form/label/div')
        #await page.keyboard.type"48500067870", delay=100)
        for i in range(random.randint(1, 3)):
            await human_wait(1, 2)
            await human_move_to(page, random.randint(100, 500), random.randint(100, 500))
        await human_move_to(page, random.randint(100, 500), random.randint(100, 500))
        #await human_wait(8,10)
        await simulate_reading(page, 2, 5)
        #await human_scroll(page, 400, 500)
        await human_click(page, "#app > div > div.q-page-container.app-page-container > main > form > div > button > span.q-btn__content.text-center.col.items-center.q-anchor--skip.justify-center.row > span")
        #await page.screenshot(path="login.png", full_page=True)
        await page.screenshot(path="certidao.png", full_page=True)
        await human_click(page, '//*[@id="q-portal--dialog--1"]/div/div[2]/div/div[3]/button[2]')
        await page.screenshot(path="solicitado.png", full_page=True)
        
        print("Sucesso")




if __name__ == "__main__":
    asyncio.run(main())



"""
Basic example using Abrasio in local (free) mode with Patchright.

This example demonstrates how to use Abrasio with maximum anti-detection:
- Uses Patchright (undetected Playwright fork)
- Uses real Chrome (channel="chrome")
- Uses persistent context for better fingerprint
- No custom user_agent (creates fingerprint mismatch)
- No viewport override (no_viewport for realistic behavior)

Before running:
    pip install abrasio
    patchright install chrome  # Install real Chrome, not Chromium
"""

import asyncio
from abrasio import Abrasio
from abrasio.utils import (
    human_click,
    human_type,
    human_scroll,
    human_move_to,
    human_wait,
    simulate_reading,
    random_delay,
)

async def main():
    # Local mode - no API key needed
    # headless=False recommended for maximum stealth

    async with Abrasio(api_key ="sk_live_J3x6He9d35C1tCSt2mmuOtcNIFk_rVtwWdU-R_donSo",
                    #api_key="sk_live_v9mZmBNvZHwblE7-hOwCQ3xgyFE7oeo0kTSu8Nt6p34",
                    region="BR",
                    proxy={"server": "http://network.joinmassive.com:65534", "username": "mpuW15al5h-country-BR-subdivision-SP", "password": "moS1BoA2RbKFIwu9BUr0"},
                    humanize=True,
                    headless=False
                    ) as browser:
        page = await browser.new_page()

        # Test against bot detection sites
        print("Testing against bot detection...")

        # await page.goto("https://www.gov.br")
        # await human_wait(10, 15)
        # await page.wait_for_timeout(3000)
        # await page.screenshot(path="gov.png", full_page=True)
        # print("gov test saved to gov.png")
        
        # Test 1: recaptcha
        await page.goto("https://recaptcha-demo.appspot.com/recaptcha-v3-request-scores.php")
        await human_wait(30, 45)
        await page.wait_for_timeout(3000)
        await page.screenshot(path="recaptcha.png", full_page=True)
        print("recaptcha test saved to recaptcha.png")
        # Test 1: browserscan
        await page.goto("https://browserscan.net")
        await human_wait(10, 15)
        await page.wait_for_timeout(3000)
        await page.screenshot(path="browserscan.png", full_page=True)
        print("browserscan test saved to browserscan.png")

        await page.goto("https://bot.sannysoft.com/")
        await human_wait(10, 15)
        await page.wait_for_timeout(3000)
        await page.screenshot(path="test_sannysoft.png", full_page=True)
        print("Sannysoft test saved to test_sannysoft.png")

        # Test 2: Fingerprint.com (BotD)
        await page.goto("https://demo.fingerprint.com/playground")
        await human_wait(10, 15)
        await page.screenshot(path="test_fingerprint.png", full_page=True)
        print("Fingerprint.com test saved to test_fingerprint.png")

        # Test 3: CreepJS
        await page.goto("https://abrahamjuliot.github.io/creepjs/")
        await human_wait(10, 15)
        await page.screenshot(path="test_creepjs.png", full_page=True)
        print("CreepJS test saved to test_creepjs.png")

        print("\nCheck the screenshots to verify anti-detection is working!")
        print("Green = pass, Red = fail")

        # Keep browser open for manual inspection
        input("\nPress Enter to close browser...")


if __name__ == "__main__":
    asyncio.run(main())



"""
Basic example using Abrasio in cloud (paid) mode.

This example demonstrates how to use Abrasio with the cloud browser
service using an API key.

Before running:
    pip install abrasiohttps://nopecha.com/setup#sub_1T4CnfCRwBwvt6ptJ7ibOS5S
    export ABRASIO_API_KEY=sk_live_xxx
"""

import asyncio
import os
import time
from abrasio import Abrasio, FingerprintConfig, AbrasioConfig
from abrasio.utils import human_scroll, human_wait, simulate_reading, human_click, human_type


async def main():
    # Get API key from environment
    api_key = "sk_live_v9mZmBNvZHwblE7-hOwCQ3xgyFE7oeo0kTSu8Nt6p34"#"sk_live_AUEnBxlYgqcm4Cc6smA814Vzk067r6bSiIV7cunCkVA"#"sk_live_Qct3WeYuLhXRxPJdLpP2X8X0YqCwUyLUhPywXwmBsyk"#os.getenv("ABRASIO_API_KEY")
    if not api_key:
        print("Set ABRASIO_API_KEY environment variable to use cloud mode")
        print("Example: export ABRASIO_API_KEY=sk_live_xxx")
        return
    config:AbrasioConfig = FingerprintConfig(
        webgl=True,
        webrtc=True,
        )
    # Cloud mode - with API key and region
    # For local testing use: api_url="http://localhost:8000"
    async with Abrasio(
        api_key ="sk_live_J3x6He9d35C1tCSt2mmuOtcNIFk_rVtwWdU-R_donSo",
        region="br",
        proxy={"server": "http://network.joinmassive.com:65534", "username": "mpuW15al5h-country-BR-subdivision-SP", "password": "moS1BoA2RbKFIwu9BUr0"},
        #api_key=api_key,
        # api_url="http://localhost:8000",  # Uncomment for local testing
        #region="BR",
        #config=config,
        device="mobile",
        url="https://www.gov.br",
        profile_id="355161aee2a8",
        #proxy={"server": "gw-open.netnut.net:5959", "username": "Scrapetech-res-br", "password": "Wg0d5619HrBLesl"},
        #proxy=f'http://Scrapetech-res-us:Wg0d5619HrBLesl@gw-open.netnut.net:5959'
          # Disable WebGL and Canvas for testing
        #headless=True,
        #device="mobile",
        headless=False,
        
    ) as browser:
        page = await browser.new_page()
        # Live view URL (if enabled on server)
        if browser.live_view_url:
            print(f"Watch live: {browser.live_view_url}")
        
        await page.goto("https://cidadao.mg.gov.br/#/login", wait_until="domcontentloaded")
        await human_wait(5,7)  # Wait for login page to load
        #await page.locator("//*[contains(text(), 'Aceitar')]").click()
        #await page.screenshot(path="loginpage.png", full_page=True)
        print("Login page screenshot saved to loginpage.png")
        await page.locator(".govBrBtn").is_visible()
        await page.locator(".govBrBtn").click()

        await page.wait_for_selector("#accountId")
        #await page.locator("#accountId").click()
        #cpf = input("Enter the CPF: ")
        await human_type(page, "48500067870", "#accountId")
        #await page.keyboard.type"48500067870", delay=100)

        await page.locator('#enter-account-id').click()
        #await page.screenshot(path="login.png", full_page=True)
        await human_wait(20,40)
        await page.locator("#password").is_visible()
        #await page.screenshot(path="senha.png", full_page=True)
        await page.locator("#password").click()
        #senha = input("Enter the password: ")
        await page.keyboard.type("Ovalle#442", delay=100)

        await page.locator('#submit-button').click()
       
        await page.wait_for_selector(".gdd-close-btn")
        await page.locator(".gdd-close-btn").click()
        await page.locator("#otpInput").is_visible()
        await page.screenshot(path="otp.png", full_page=True)
        await page.locator("#otpInput").click()
        codigo = input("Enter the OTP code: ")
        await page.keyboard.type(codigo, delay=100)
        await page.mouse.move(5,5)
        await page.locator("#enter-offline-2fa-code").click()
        cookies = await page.context.cookies()  

        await page.wait_for_selector(".main-menu")
        await page.locator(".main-menu").click()

        await page.wait_for_selector("//*[contains(text(), 'Veículos e Condutores (Trânsito)')]")
        await page.locator("//*[contains(text(), 'Veículos e Condutores (Trânsito)')]").click()
        await human_wait(2,3)
        await human_click(page, 'body > app-root > app-cookie-consent-banner > div > div > div.cookie-buttons > p-button:nth-child(2) > button')
        await page.screenshot(path="menu.png", full_page=True)
        await page.wait_for_selector('//*[@id="outlet"]/app-servicos/div/div/div[4]/div[1]/button')
        await page.locator('//*[@id="outlet"]/app-servicos/div/div/div[4]/div[1]/button').click()
        await page.get_by_text("Situação do Veículo").scroll_into_view_if_needed()
        #await human_scroll(page, 900, 1300)
        await human_click(page, "//*[contains(text(), 'Situação do Veículo')]")

        await human_wait(4,10)
        await simulate_reading(page, 2, 8)
        await human_click(page, "#placa")
        await human_type(page, "RVX1D55", "#placa")
        await human_type(page, "9BWAG45U6PT098548", "#chassi")

        async with page.expect_response(
            lambda r: "mgapp.mg.gov.br/egov-servicos-web/rest/veiculos/situacao" in r.url
        ) as response_info:
            await human_click(page, "//*[contains(text(), 'Pesquisar')]")

        #response = await response_info.value
        #veiculo_json = await response.json()
        await human_wait(5,10)
        await page.screenshot(path="situacao.png", full_page=True)
        #print(veiculo_json)
        print(cookies)
        print("Sucesso")




if __name__ == "__main__":
    asyncio.run(main())



"""
Basic example using Abrasio in cloud (paid) mode.

This example demonstrates how to use Abrasio with the cloud browser
service using an API key.

Before running:
    pip install abrasio
    export ABRASIO_API_KEY=sk_live_xxx
"""

import asyncio
import os
import time
from abrasio import Abrasio, FingerprintConfig, AbrasioConfig
from abrasio.utils import human_scroll, human_wait, simulate_reading, human_click, human_type


async def main():
    # Get API key from environment
    api_key = "sk_live_J3x6He9d35C1tCSt2mmuOtcNIFk_rVtwWdU-R_donSo"#"sk_live_Qct3WeYuLhXRxPJdLpP2X8X0YqCwUyLUhPywXwmBsyk"#os.getenv("ABRASIO_API_KEY")
    if not api_key:
        print("Set ABRASIO_API_KEY environment variable to use cloud mode")
        print("Example: export ABRASIO_API_KEY=sk_live_xxx")
        return
    config:AbrasioConfig = FingerprintConfig(
        webgl=True,
        webrtc=True,
        )
    # Cloud mode - with API key and region
    # For local testing use: api_url="http://localhost:8000"
    async with Abrasio(
        api_key=api_key,
        # api_url="http://localhost:8000",  # Uncomment for local testing
        region="br",
        url="https://google.com.br",
        proxy=None,
          # Disable WebGL and Canvas for testing
        device="desktop",
        
        #headless=False
    ) as browser:
        page = await browser.new_page()
        # Live view URL (if enabled on server)
        if browser.live_view_url:
            print(f"Watch live: {browser.live_view_url}")

        # Navigate to a page
        await page.goto("https://coveryourtracks.eff.org/")
        await human_wait(100, 130)  # Wait for page to load
        await page.goto("https://uber.com", wait_until="domcontentloaded")
        print(page.url)
        await page.screenshot(path="loadpage.png", full_page=True)
        await page.wait_for_selector("//*[contains(text(), 'Log in')]")
        await human_click(page, "//*[contains(text(), 'Log in')]")
        await human_wait(3, 6)  # Wait for login modal to appear
        # Get page title
        await page.wait_for_selector("#PHONE_NUMBER_or_EMAIL_ADDRESS")
        await page.screenshot(path="login.png", full_page=True)
        await human_click(page, "#PHONE_NUMBER_or_EMAIL_ADDRESS")
        await human_type(page, "jvosobhie@gmail.com", "#PHONE_NUMBER_or_EMAIL_ADDRESS")
        await human_click(page, "//*[contains(text(), 'Continuar')]")
        await page.screenshot(path="otp.png", full_page=True)
        print(await page.content())
        try:
            x = await page.frame("game-core-frame").locator("//*[contains(text(), 'Iniciar desafio')]").click()
            await page.screenshot(path="desafio.png", full_page=True)
            await human_click(page, x= x["x"], y= x["y"])
        except:
            print("Timeout waiting for 'Iniciar desafio' selector")
        await page.screenshot(path="desafiook.png", full_page=True)
        telefone = input("Enter the OTP sent to your email: ")
        await human_type(page, telefone, '#wrapper > div.aq.ar.as.at > div > div > div > div:nth-child(1) > div.ae.af.es > div > div > div:nth-child(1)')
        try:
            await page.wait_for_selector("#PASSWORD")
            await human_click(page, "#PASSWORD")
            await human_type(page, "Ovalle#442", "#PASSWORD")
            await page.screenshot(path="senha.png", full_page=True)
            await human_click(page, "//*[contains(text(), 'Avançar')]")
        except:
            print("Timeout waiting for #PASSWORD selector")
        await page.screenshot(path="loginfeito.png", full_page=True)
        await human_wait(5, 10)  # Wait for login to complete
        await page.goto("https://m.uber.com/go/home", wait_until="domcontentloaded")
        await page.screenshot(path="home.png", full_page=True)
        await page.wait_for_selector("#wrapper > div.css-dqxzrQ > div > main > div > section > div > div > section > div.css-kappr > div > div.css-iBcnDJ > div.css-hSRbgy > ul > li:nth-child(1) > div > div.css-hSpIzb > div > div.css-gvRkiA")
        await human_click(page, "#wrapper > div.css-dqxzrQ > div > main > div > section > div > div > section > div.css-kappr > div > div.css-iBcnDJ > div.css-hSRbgy > ul > li:nth-child(1) > div > div.css-hSpIzb > div > div.css-gvRkiA")  
        await human_type(page, "Internacional", "#wrapper > div.css-dqxzrQ > div > main > div > section > div > div > section > div.css-kappr > div > div.css-iBcnDJ > div.css-hSRbgy > ul > li:nth-child(1) > div > div.css-hSpIzb > div > div.css-gvRkiA")
        await human_click(page, "#wrapper > div.css-dqxzrQ > div > main > div > section > div > div > section > div.css-kappr > div > div.css-iBcnDJ > div.css-hSRbgy > ul > li:nth-child(2) > div > div.css-kAbTNm > div")
        await human_type(page, "Club Severino", '#wrapper > div.css-dqxzrQ > div > main > div > section > div > div > section > div.css-kappr > div > div.css-iBcnDJ > div.css-hSRbgy > ul > li:nth-child(2) > div > div.css-kAbTNm > div')
        await human_click(page, "//*[contains(text(), 'Pesquisar')]")
        await human_wait(7, 15)  # Wait for search results
        await page.screenshot(path="uber_search.png", full_page=True)
        


if __name__ == "__main__":
    asyncio.run(main())
